<?php

namespace Drupal\edlp_studio;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the Fil entity.
 *
 * @see \Drupal\edlp_studio\Entity\Fil.
 */
class FilAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\edlp_studio\Entity\FilInterface $entity */
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          if($account->hasPermission('view own unpublished fil entities') && $account->isAuthenticated() && $account->id() == $entity->getOwnerId() ){
            return AccessResult::allowed()->cachePerPermissions()->cachePerUser()->addCacheableDependency($entity);
          }else{
            return AccessResult::allowedIfHasPermission($account, 'view any unpublished fil entities');
          }
        }
        return AccessResult::allowedIfHasPermission($account, 'view published fil entities');

      case 'update':
        if($account->hasPermission('edit own fil entities') && $account->isAuthenticated() && $account->id() == $entity->getOwnerId() ){
          return AccessResult::allowed()->cachePerPermissions()->cachePerUser()->addCacheableDependency($entity);
        }else{
          return AccessResult::allowedIfHasPermission($account, 'edit any fil entities');
        }

      case 'delete':
        if($account->hasPermission('delete own fil entities') && $account->isAuthenticated() && $account->id() == $entity->getOwnerId() ){
          return AccessResult::allowed()->cachePerPermissions()->cachePerUser()->addCacheableDependency($entity);
        }else{
          return AccessResult::allowedIfHasPermission($account, 'delete fil entities');
        }
    }

    // Unknown operation, no opinion.
    return AccessResult::neutral();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'add fil entities');
  }

}
